@@ -27,7 +27,7 @@ sub check_statement_expression
     my $cache_name = $self->_cache_name(qw(feature statement expression));
     my $check_sub  = sub {
         my $prologue = defined $options->{prologue} ? $options->{prologue} : "";
-	my $decl = "#define STMT_EXPR ({ 1; })";
+        my $decl     = "#define STMT_EXPR ({ 1; })";
 
         my $have_stmt_expr = $self->compile_if_else(
             $self->lang_build_bool_test($prologue, "STMT_EXPR", $decl),
@@ -71,16 +71,21 @@ sub check_lmu_prerequisites
     my $self = shift->_get_instance();
 
     $self->check_produce_loadable_xs_build() or die "Can't produce loadable XS module";
+    $self->check_default_headers();
     $self->check_all_headers(qw(time.h sys/time.h));
     $self->check_funcs([qw(time)]);
 
-    unless($self->check_types([qw(size_t ssize_t)]))
+    unless ($self->check_types([qw(size_t ssize_t)]))
     {
-        $self->check_sizeof_types(["int", "long", "long long", "ptr"], {
-            prologue => $self->_default_includes . <<EOPTR
+        $self->check_sizeof_types(
+            ["int", "long", "long long", "ptr"],
+            {
+                prologue => $self->_default_includes
+                  . <<EOPTR
 typedef void * ptr;
 EOPTR
-        });
+            }
+        );
     }
     $self->check_builtin("expect");
     $self->check_statement_expression();
