@@ -1,7 +1,9 @@
-
 use Test::More;
 use Test::LMU;
 
+use POSIX qw(setlocale LC_COLLATE);
+setlocale(LC_COLLATE, "C");
+
 my @list = reverse 'AA' .. 'ZZ';
 my ($min, $max) = minmaxstr @list;
 is($min, 'AA');
@@ -38,4 +40,3 @@ leak_free_ok(
 );
 
 done_testing;
-
